@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ConfirmRelease;
 {
-  $Dist::Zilla::Plugin::ConfirmRelease::VERSION = '4.300020';
+  $Dist::Zilla::Plugin::ConfirmRelease::VERSION = '4.300034';
 }
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -8,7 +8,6 @@ with 'Dist::Zilla::Role::BeforeRelease';
 
 use namespace::autoclean;
 
-use ExtUtils::MakeMaker ();
 use Moose::Autobox;
 
 sub before_release {
@@ -36,8 +35,8 @@ sub before_release {
 __PACKAGE__->meta->make_immutable;
 1;
 
-
 __END__
+
 =pod
 
 =head1 NAME
@@ -46,7 +45,7 @@ Dist::Zilla::Plugin::ConfirmRelease - prompt for confirmation before releasing
 
 =head1 VERSION
 
-version 4.300020
+version 4.300034
 
 =head1 DESCRIPTION
 
@@ -58,20 +57,15 @@ The default is "no", but you can set the environment variable
 C<DZIL_CONFIRMRELEASE_DEFAULT> to "yes" if you just want to hit enter to
 release.
 
-This plugin uses C<ExtUtils::MakeMaker::prompt()>, so setting
-C<PERL_MM_USE_DEFAULT> to a true value will accept the default without
-prompting.
-
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
