@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::TestRelease;
 {
-  $Dist::Zilla::Plugin::TestRelease::VERSION = '4.300003';
+  $Dist::Zilla::Plugin::TestRelease::VERSION = '4.300034';
 }
 use Moose;
 with 'Dist::Zilla::Role::BeforeRelease';
@@ -9,7 +9,6 @@ with 'Dist::Zilla::Role::BeforeRelease';
 use namespace::autoclean;
 
 
-use Archive::Tar;
 use File::pushd ();
 use Moose::Autobox;
 use Path::Class ();
@@ -25,6 +24,8 @@ sub before_release {
 
   $self->log("Extracting $tgz to $tmpdir");
 
+  require Archive::Tar;
+
   my @files = do {
     my $wd = File::pushd::pushd($tmpdir);
     Archive::Tar->extract_archive("$tgz");
@@ -34,7 +35,7 @@ sub before_release {
     unless @files;
 
   # Run tests on the extracted tarball:
-  my $target = $tmpdir->subdir( $self->zilla->built_in->dir_list(-1) );
+  my $target = $tmpdir->subdir( $self->zilla->dist_basename );
 
   local $ENV{RELEASE_TESTING} = 1;
   local $ENV{AUTHOR_TESTING} = 1;
@@ -48,6 +49,7 @@ __PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -56,7 +58,7 @@ Dist::Zilla::Plugin::TestRelease - extract archive and run tests before releasin
 
 =head1 VERSION
 
-version 4.300003
+version 4.300034
 
 =head1 DESCRIPTION
 
@@ -67,7 +69,7 @@ is left in place.  If the tests pass, the temporary directory is cleaned up and
 the release process continues.
 
 This will set the RELEASE_TESTING and AUTHOR_TESTING env vars while running the
-testsuite.
+test suite.
 
 =head1 CREDITS
 
@@ -79,10 +81,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
