@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::PPI;
 {
-  $Dist::Zilla::Role::PPI::VERSION = '4.300020';
+  $Dist::Zilla::Role::PPI::VERSION = '4.300034';
 }
 # ABSTRACT: a role for plugins which use PPI
 use Moose::Role;
@@ -47,7 +47,7 @@ sub document_assigns_to_variable {
 
   my $finder = sub {
     my $node = $_[1];
-    return 1 if $node->isa('PPI::Statement') && $node->content =~ /\Q$variable\E\s*=/sm;
+    return 1 if $node->isa('PPI::Statement') && $node->content =~ /(?<!\\)\Q$variable\E\s*=/sm;
     return 0;
   };
 
@@ -60,6 +60,7 @@ sub document_assigns_to_variable {
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -68,7 +69,7 @@ Dist::Zilla::Role::PPI - a role for plugins which use PPI
 
 =head1 VERSION
 
-version 4.300020
+version 4.300034
 
 =head1 DESCRIPTION
 
@@ -108,10 +109,9 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2013 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
